import { HelmInstallFlags } from 'packages-modules/container-helm/server/src/constants/constants';
import { HelmInspectFlags } from 'packages-modules/container-helm/server/src/constants/constants';
import { HelmRepoFlags } from 'packages-modules/container-helm/server/src/constants/constants';
import { HelmSearchFlags } from 'packages-modules/container-helm/server/src/constants/constants';
import { HelmCommandsGlobalFlags } from 'packages-modules/container-helm/server/src/constants/constants';
import { SternCmdFlags } from 'packages-modules/container-logger/server/src/interfaces/enum';
import { KubectlCmdFlags } from 'packages-modules/container-logger/server/src/interfaces/enum';
import { GraphQLResolveInfo, GraphQLScalarType, GraphQLScalarTypeConfig } from 'graphql';
import { MyContext } from '../context';
export declare type Maybe<T> = T | null;
export declare type Exact<T extends {
    [key: string]: unknown;
}> = {
    [K in keyof T]: T[K];
};
export declare type MakeOptional<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]?: Maybe<T[SubKey]>;
};
export declare type MakeMaybe<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]: Maybe<T[SubKey]>;
};
export declare type EnumResolverSignature<T, AllowedValues = any> = {
    [key in keyof T]?: AllowedValues;
};
export declare type RequireFields<T, K extends keyof T> = {
    [X in Exclude<keyof T, K>]?: T[X];
} & {
    [P in K]-?: NonNullable<T[P]>;
};
/** All built-in and custom scalars, mapped to their actual values */
export declare type Scalars = {
    ID: string;
    String: string;
    Boolean: boolean;
    Int: number;
    Float: number;
    AnyObject: any;
    Date: any;
    DateTime: any;
    JSON: any;
    JSONObject: any;
    Observable: any;
    Time: any;
    URI: any;
    URIInput: any;
};
export declare type IAdminIdeSettings = {
    dummy?: Maybe<Scalars['Int']>;
};
export declare const enum ICacheControlScope {
    Public = "PUBLIC",
    Private = "PRIVATE"
}
/** Represents a null return value. */
export declare type IEmptyResponse = {
    alwaysNil?: Maybe<Scalars['String']>;
};
export declare type IFieldError = {
    field: Scalars['String'];
    message: Scalars['String'];
};
export declare type IGenerateSshKeysRequest = {
    name?: Maybe<Scalars['String']>;
    comment?: Maybe<Scalars['String']>;
};
export declare type IGeoLocation = {
    type?: Maybe<Scalars['String']>;
    coordinates?: Maybe<Array<Maybe<Scalars['Float']>>>;
};
/**
 * Input geometry of the location.
 * List the `longitude` first and then `latitude`
 *  - Validate longitude values are between `-180` and `180`
 *  - Validate latitude values are between `-90` and `90`
 */
export declare type IGeoLocationInput = {
    type?: Maybe<Scalars['String']>;
    coordinates?: Maybe<Array<Maybe<Scalars['Float']>>>;
};
/**  Helm Commands that are supported  */
export declare const enum IHelmCommands {
    Inspect = "inspect",
    Repo = "repo",
    Search = "search",
    Install = "install",
    Fetch = "fetch",
    Template = "template"
}
export { HelmCommandsGlobalFlags };
export declare const enum IHelmFetchFlags {
    Version = "VERSION"
}
export declare type IHelmGetChartResourcesRequest = {
    chartName?: Maybe<Scalars['String']>;
    chartVersion?: Maybe<Scalars['String']>;
    values?: Maybe<Scalars['AnyObject']>;
    setValues?: Maybe<Scalars['AnyObject']>;
};
export declare const enum IHelmInspectCommands {
    Chart = "chart",
    Readme = "readme",
    Values = "values"
}
export { HelmInspectFlags };
export declare type IHelmInspectRequest = {
    helmInspectCommand?: Maybe<IHelmInspectCommands>;
    chartName?: Maybe<Scalars['String']>;
    OptionalInspectFlags?: Maybe<Array<Maybe<IOptionalInspectFlags>>>;
    OptionalGlobalFlags?: Maybe<Array<Maybe<HelmCommandsGlobalFlags>>>;
};
export { HelmInstallFlags };
export declare type IHelmInstallTillerRequest = {
    nameSpace?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
};
export declare type IHelmRepoAddRequest = {
    helmRepoCommand: IHelmRepoCommands;
    repoName: Scalars['String'];
    url: Scalars['String'];
    OptionalRepoFlags?: Maybe<Array<Maybe<IOptionalRepoFlags>>>;
    OptionalGlobalFlags?: Maybe<Array<Maybe<HelmCommandsGlobalFlags>>>;
};
export declare const enum IHelmRepoCommands {
    Add = "add",
    Update = "update"
}
export { HelmRepoFlags };
export { HelmSearchFlags };
export declare type IHelmSearchRequest = {
    OptionalRegex?: Maybe<Scalars['String']>;
    OptionalSearchFlags?: Maybe<Array<Maybe<IOptionalSearchFlags>>>;
    OptionalGlobalFlags?: Maybe<Array<Maybe<HelmCommandsGlobalFlags>>>;
};
export declare type IHelmService = {
    inspect?: Maybe<Scalars['AnyObject']>;
    repoAdd?: Maybe<Scalars['AnyObject']>;
    search?: Maybe<Scalars['AnyObject']>;
    installTiller?: Maybe<Scalars['AnyObject']>;
    getResources?: Maybe<ITotalConsumption>;
};
export declare type IHelmServiceInspectArgs = {
    helmInspectRequest?: Maybe<IHelmInspectRequest>;
};
export declare type IHelmServiceRepoAddArgs = {
    helmRepoAddRequest?: Maybe<IHelmRepoAddRequest>;
};
export declare type IHelmServiceSearchArgs = {
    helmSearchRequest?: Maybe<IHelmSearchRequest>;
};
export declare type IHelmServiceInstallTillerArgs = {
    helmInstallTillerREquest?: Maybe<IHelmInstallTillerRequest>;
};
export declare type IHelmServiceGetResourcesArgs = {
    helmGetChartResourceRequest?: Maybe<IHelmGetChartResourcesRequest>;
};
export declare const enum IHelmServiceAction {
    Inspect = "inspect",
    Search = "search",
    RepoAdd = "repoAdd",
    InstallTiller = "installTiller",
    GetResources = "getResources"
}
export declare type IIKubectlLogSettings = {
    subTopic?: Maybe<Scalars['String']>;
};
export declare type IIResourceUtilizationSettings = {
    subTopic?: Maybe<Scalars['String']>;
    adminApiNamespace?: Maybe<Scalars['String']>;
};
export declare type IISshKeySettings = {
    subTopic?: Maybe<Scalars['String']>;
    sshNamespace?: Maybe<Scalars['String']>;
};
export declare const enum IKubectlCmd {
    Stern = "stern",
    Kubectl = "kubectl"
}
export { KubectlCmdFlags };
export declare type IKubectlExposePortRequest = {
    podName?: Maybe<Scalars['String']>;
    nameSpace?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
    port?: Maybe<Scalars['Int']>;
    targetPort?: Maybe<Scalars['Int']>;
    protocol?: Maybe<IKubectlPortPortocol>;
};
export declare type IKubectlLogGetRequest = {
    labelKey: Scalars['String'];
    labelValue: Scalars['String'];
    nameSpace: Scalars['String'];
    tail?: Maybe<Scalars['Int']>;
    stream?: Maybe<Scalars['Boolean']>;
    timeStamp?: Maybe<Scalars['Boolean']>;
};
export declare type IKubectlLogSettings = IIKubectlLogSettings & {
    subTopic?: Maybe<Scalars['String']>;
};
export declare type IKubectlLoggerService = {
    getLogs?: Maybe<Scalars['AnyObject']>;
};
export declare type IKubectlLoggerServiceGetLogsArgs = {
    logRequest?: Maybe<IKubectlLogGetRequest>;
};
export declare const enum IKubectlLoggerServiceAction {
    Stream = "stream"
}
export declare const enum IKubectlPortPortocol {
    Tcp = "TCP",
    Udp = "UDP"
}
export declare type IKubectlService = {
    exposePort?: Maybe<Scalars['Boolean']>;
};
export declare type IKubectlServiceExposePortArgs = {
    exposePortRequest?: Maybe<IKubectlExposePortRequest>;
};
export declare const enum IKubectlServiceAction {
    ExposePort = "exposePort"
}
export declare const enum IMailTemplateId {
    Dummy = "dummy"
}
export declare const enum IMoleculerCronServiceName {
    Dummy = "dummy"
}
/**  All Moleculer Topic names are extended from this. */
export declare const enum IMoleculerServiceName {
    HelmService = "HelmService",
    KubectlLoggerService = "KubectlLoggerService",
    KubectlService = "KubectlService",
    SshKeyService = "SshKeyService",
    Dummy = "dummy"
}
export declare type IMutation = {
    AddSshKey?: Maybe<ISshKey>;
    DeleteSshKey?: Maybe<Scalars['Boolean']>;
    UpdateSshKey?: Maybe<ISshKey>;
    dummy?: Maybe<Scalars['Int']>;
};
export declare type IMutationAddSshKeyArgs = {
    key: ISshKeyInput;
};
export declare type IMutationDeleteSshKeyArgs = {
    id: Scalars['ID'];
};
export declare type IMutationUpdateSshKeyArgs = {
    id: Scalars['ID'];
    key: ISshKeyInput;
};
/** An object with an ID. */
export declare type INode = {
    /** The ID of the node. */
    id: Scalars['ID'];
};
export declare type IOptionalInspectFlags = {
    flag?: Maybe<HelmInspectFlags>;
    value: Scalars['String'];
};
export declare type IOptionalRepoFlags = {
    flag?: Maybe<HelmRepoFlags>;
    value?: Maybe<Scalars['String']>;
};
export declare type IOptionalSearchFlags = {
    flag?: Maybe<HelmSearchFlags>;
    value?: Maybe<Scalars['String']>;
};
export declare type IPageInfo = {
    hasNextPage: Scalars['Boolean'];
};
export declare type IQuery = {
    GetSshKey?: Maybe<ISshKey>;
    /** Looks up a node by ID. */
    node?: Maybe<INode>;
};
export declare type IQueryGetSshKeyArgs = {
    id: Scalars['ID'];
};
export declare type IQueryNodeArgs = {
    id: Scalars['ID'];
};
export declare type IRequestsLimits = {
    storage?: Maybe<Scalars['String']>;
    cpu?: Maybe<Scalars['String']>;
    memory?: Maybe<Scalars['String']>;
};
export declare type IResources = {
    requests?: Maybe<Array<Maybe<IRequestsLimits>>>;
    limits?: Maybe<Array<Maybe<IRequestsLimits>>>;
};
export declare type ISort = {
    key: Scalars['String'];
    value: ISortEnum;
};
export declare const enum ISortEnum {
    Asc = "ASC",
    Desc = "DESC"
}
export declare type ISshKey = {
    id?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
    key?: Maybe<Scalars['String']>;
    pubKey?: Maybe<Scalars['String']>;
    keyType?: Maybe<Scalars['String']>;
    createdAt?: Maybe<Scalars['String']>;
};
export declare type ISshKeyInput = {
    id?: Maybe<Scalars['String']>;
    name: Scalars['String'];
    pubKey: Scalars['String'];
    key: Scalars['String'];
    keyType?: Maybe<ISshKeyType>;
};
export declare type ISshKeyModel = {
    id?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
    keyType?: Maybe<Scalars['String']>;
    createdAt?: Maybe<Scalars['String']>;
};
export declare type ISshKeyService = {
    addSshKey?: Maybe<ISshKeyModel>;
    deleteSshKey?: Maybe<Scalars['Boolean']>;
    generateKeys?: Maybe<ISshKeyModel>;
    getSshKey?: Maybe<ISshKeyModel>;
    updateSshKey?: Maybe<ISshKeyModel>;
};
export declare type ISshKeyServiceAddSshKeyArgs = {
    input?: Maybe<ISshKeyInput>;
};
export declare type ISshKeyServiceDeleteSshKeyArgs = {
    id?: Maybe<Scalars['String']>;
};
export declare type ISshKeyServiceGenerateKeysArgs = {
    input?: Maybe<IGenerateSshKeysRequest>;
};
export declare type ISshKeyServiceGetSshKeyArgs = {
    id?: Maybe<Scalars['String']>;
};
export declare type ISshKeyServiceUpdateSshKeyArgs = {
    id?: Maybe<Scalars['String']>;
    input?: Maybe<ISshKeyInput>;
};
export declare const enum ISshKeyServiceAction {
    GetSshKey = "getSshKey",
    DeleteSshKey = "deleteSshKey",
    AddSshKey = "addSshKey",
    GenerateKeys = "generateKeys",
    UpdateSshKey = "updateSshKey"
}
export declare type ISshKeySettings = IISshKeySettings & {
    subTopic?: Maybe<Scalars['String']>;
    sshNamespace?: Maybe<Scalars['String']>;
};
export declare const enum ISshKeyType {
    Rsa = "RSA",
    Ed25519 = "ED25519"
}
export { SternCmdFlags };
export declare type ISubscription = {
    dummy?: Maybe<Scalars['Int']>;
};
export declare type ITotalConsumption = {
    request?: Maybe<IRequestsLimits>;
    limits?: Maybe<IRequestsLimits>;
};
export declare type ResolverTypeWrapper<T> = Promise<T> | T;
export declare type ResolverWithResolve<TResult, TParent, TContext, TArgs> = {
    resolve: ResolverFn<TResult, TParent, TContext, TArgs>;
};
export declare type LegacyStitchingResolver<TResult, TParent, TContext, TArgs> = {
    fragment: string;
    resolve: ResolverFn<TResult, TParent, TContext, TArgs>;
};
export declare type NewStitchingResolver<TResult, TParent, TContext, TArgs> = {
    selectionSet: string;
    resolve: ResolverFn<TResult, TParent, TContext, TArgs>;
};
export declare type StitchingResolver<TResult, TParent, TContext, TArgs> = LegacyStitchingResolver<TResult, TParent, TContext, TArgs> | NewStitchingResolver<TResult, TParent, TContext, TArgs>;
export declare type Resolver<TResult, TParent = {}, TContext = {}, TArgs = {}> = ResolverFn<TResult, TParent, TContext, TArgs> | ResolverWithResolve<TResult, TParent, TContext, TArgs> | StitchingResolver<TResult, TParent, TContext, TArgs>;
export declare type ResolverFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => Promise<TResult> | TResult;
export declare type SubscriptionSubscribeFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => AsyncIterator<TResult> | Promise<AsyncIterator<TResult>>;
export declare type SubscriptionResolveFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => TResult | Promise<TResult>;
export interface SubscriptionSubscriberObject<TResult, TKey extends string, TParent, TContext, TArgs> {
    subscribe: SubscriptionSubscribeFn<{
        [key in TKey]: TResult;
    }, TParent, TContext, TArgs>;
    resolve?: SubscriptionResolveFn<TResult, {
        [key in TKey]: TResult;
    }, TContext, TArgs>;
}
export interface SubscriptionResolverObject<TResult, TParent, TContext, TArgs> {
    subscribe: SubscriptionSubscribeFn<any, TParent, TContext, TArgs>;
    resolve: SubscriptionResolveFn<TResult, any, TContext, TArgs>;
}
export declare type SubscriptionObject<TResult, TKey extends string, TParent, TContext, TArgs> = SubscriptionSubscriberObject<TResult, TKey, TParent, TContext, TArgs> | SubscriptionResolverObject<TResult, TParent, TContext, TArgs>;
export declare type SubscriptionResolver<TResult, TKey extends string, TParent = {}, TContext = {}, TArgs = {}> = ((...args: any[]) => SubscriptionObject<TResult, TKey, TParent, TContext, TArgs>) | SubscriptionObject<TResult, TKey, TParent, TContext, TArgs>;
export declare type TypeResolveFn<TTypes, TParent = {}, TContext = {}> = (parent: TParent, context: TContext, info: GraphQLResolveInfo) => Maybe<TTypes> | Promise<Maybe<TTypes>>;
export declare type IsTypeOfResolverFn<T = {}, TContext = {}> = (obj: T, context: TContext, info: GraphQLResolveInfo) => boolean | Promise<boolean>;
export declare type NextResolverFn<T> = () => Promise<T>;
export declare type DirectiveResolverFn<TResult = {}, TParent = {}, TContext = {}, TArgs = {}> = (next: NextResolverFn<TResult>, parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => TResult | Promise<TResult>;
/** Mapping between all available schema types and the resolvers types */
export declare type IResolversTypes = {
    AdminIdeSettings: ResolverTypeWrapper<IAdminIdeSettings>;
    Int: ResolverTypeWrapper<Scalars['Int']>;
    AnyObject: ResolverTypeWrapper<Scalars['AnyObject']>;
    CacheControlScope: ICacheControlScope;
    Date: ResolverTypeWrapper<Scalars['Date']>;
    DateTime: ResolverTypeWrapper<Scalars['DateTime']>;
    EmptyResponse: ResolverTypeWrapper<IEmptyResponse>;
    String: ResolverTypeWrapper<Scalars['String']>;
    FieldError: ResolverTypeWrapper<IFieldError>;
    GenerateSSHKeysRequest: IGenerateSshKeysRequest;
    GeoLocation: ResolverTypeWrapper<IGeoLocation>;
    Float: ResolverTypeWrapper<Scalars['Float']>;
    GeoLocationInput: IGeoLocationInput;
    HelmCommands: IHelmCommands;
    HelmCommandsGlobalFlags: HelmCommandsGlobalFlags;
    HelmFetchFlags: IHelmFetchFlags;
    HelmGetChartResourcesRequest: ResolverTypeWrapper<IHelmGetChartResourcesRequest>;
    HelmInspectCommands: IHelmInspectCommands;
    HelmInspectFlags: HelmInspectFlags;
    HelmInspectRequest: ResolverTypeWrapper<IHelmInspectRequest>;
    HelmInstallFlags: HelmInstallFlags;
    HelmInstallTillerRequest: ResolverTypeWrapper<IHelmInstallTillerRequest>;
    HelmRepoAddRequest: ResolverTypeWrapper<IHelmRepoAddRequest>;
    HelmRepoCommands: IHelmRepoCommands;
    HelmRepoFlags: HelmRepoFlags;
    HelmSearchFlags: HelmSearchFlags;
    HelmSearchRequest: ResolverTypeWrapper<IHelmSearchRequest>;
    HelmService: ResolverTypeWrapper<IHelmService>;
    HelmServiceAction: IHelmServiceAction;
    IKubectlLogSettings: IResolversTypes['KubectlLogSettings'];
    IResourceUtilizationSettings: never;
    ISshKeySettings: IResolversTypes['SshKeySettings'];
    JSON: ResolverTypeWrapper<Scalars['JSON']>;
    JSONObject: ResolverTypeWrapper<Scalars['JSONObject']>;
    KubectlCmd: IKubectlCmd;
    KubectlCmdFlags: KubectlCmdFlags;
    KubectlExposePortRequest: IKubectlExposePortRequest;
    KubectlLogGetRequest: ResolverTypeWrapper<IKubectlLogGetRequest>;
    Boolean: ResolverTypeWrapper<Scalars['Boolean']>;
    KubectlLogSettings: ResolverTypeWrapper<IKubectlLogSettings>;
    KubectlLoggerService: ResolverTypeWrapper<IKubectlLoggerService>;
    KubectlLoggerServiceAction: IKubectlLoggerServiceAction;
    KubectlPortPortocol: IKubectlPortPortocol;
    KubectlService: ResolverTypeWrapper<IKubectlService>;
    KubectlServiceAction: IKubectlServiceAction;
    MailTemplateId: IMailTemplateId;
    MoleculerCronServiceName: IMoleculerCronServiceName;
    MoleculerServiceName: IMoleculerServiceName;
    Mutation: ResolverTypeWrapper<{}>;
    ID: ResolverTypeWrapper<Scalars['ID']>;
    Node: never;
    Observable: ResolverTypeWrapper<Scalars['Observable']>;
    OptionalInspectFlags: ResolverTypeWrapper<IOptionalInspectFlags>;
    OptionalRepoFlags: ResolverTypeWrapper<IOptionalRepoFlags>;
    OptionalSearchFlags: ResolverTypeWrapper<IOptionalSearchFlags>;
    PageInfo: ResolverTypeWrapper<IPageInfo>;
    Query: ResolverTypeWrapper<{}>;
    RequestsLimits: ResolverTypeWrapper<IRequestsLimits>;
    Resources: ResolverTypeWrapper<IResources>;
    Sort: ISort;
    SortEnum: ISortEnum;
    SshKey: ResolverTypeWrapper<ISshKey>;
    SshKeyInput: ISshKeyInput;
    SshKeyModel: ResolverTypeWrapper<ISshKeyModel>;
    SshKeyService: ResolverTypeWrapper<ISshKeyService>;
    SshKeyServiceAction: ISshKeyServiceAction;
    SshKeySettings: ResolverTypeWrapper<ISshKeySettings>;
    SshKeyType: ISshKeyType;
    SternCmdFlags: SternCmdFlags;
    Subscription: ResolverTypeWrapper<{}>;
    Time: ResolverTypeWrapper<Scalars['Time']>;
    TotalConsumption: ResolverTypeWrapper<ITotalConsumption>;
    URI: ResolverTypeWrapper<Scalars['URI']>;
    URIInput: ResolverTypeWrapper<Scalars['URIInput']>;
};
/** Mapping between all available schema types and the resolvers parents */
export declare type IResolversParentTypes = {
    AdminIdeSettings: IAdminIdeSettings;
    Int: Scalars['Int'];
    AnyObject: Scalars['AnyObject'];
    Date: Scalars['Date'];
    DateTime: Scalars['DateTime'];
    EmptyResponse: IEmptyResponse;
    String: Scalars['String'];
    FieldError: IFieldError;
    GenerateSSHKeysRequest: IGenerateSshKeysRequest;
    GeoLocation: IGeoLocation;
    Float: Scalars['Float'];
    GeoLocationInput: IGeoLocationInput;
    HelmGetChartResourcesRequest: IHelmGetChartResourcesRequest;
    HelmInspectRequest: IHelmInspectRequest;
    HelmInstallTillerRequest: IHelmInstallTillerRequest;
    HelmRepoAddRequest: IHelmRepoAddRequest;
    HelmSearchRequest: IHelmSearchRequest;
    HelmService: IHelmService;
    IKubectlLogSettings: IResolversParentTypes['KubectlLogSettings'];
    IResourceUtilizationSettings: never;
    ISshKeySettings: IResolversParentTypes['SshKeySettings'];
    JSON: Scalars['JSON'];
    JSONObject: Scalars['JSONObject'];
    KubectlExposePortRequest: IKubectlExposePortRequest;
    KubectlLogGetRequest: IKubectlLogGetRequest;
    Boolean: Scalars['Boolean'];
    KubectlLogSettings: IKubectlLogSettings;
    KubectlLoggerService: IKubectlLoggerService;
    KubectlService: IKubectlService;
    Mutation: {};
    ID: Scalars['ID'];
    Node: never;
    Observable: Scalars['Observable'];
    OptionalInspectFlags: IOptionalInspectFlags;
    OptionalRepoFlags: IOptionalRepoFlags;
    OptionalSearchFlags: IOptionalSearchFlags;
    PageInfo: IPageInfo;
    Query: {};
    RequestsLimits: IRequestsLimits;
    Resources: IResources;
    Sort: ISort;
    SshKey: ISshKey;
    SshKeyInput: ISshKeyInput;
    SshKeyModel: ISshKeyModel;
    SshKeyService: ISshKeyService;
    SshKeySettings: ISshKeySettings;
    Subscription: {};
    Time: Scalars['Time'];
    TotalConsumption: ITotalConsumption;
    URI: Scalars['URI'];
    URIInput: Scalars['URIInput'];
};
export declare type ICacheControlDirectiveArgs = {
    maxAge?: Maybe<Scalars['Int']>;
    scope?: Maybe<ICacheControlScope>;
};
export declare type ICacheControlDirectiveResolver<Result, Parent, ContextType = MyContext, Args = ICacheControlDirectiveArgs> = DirectiveResolverFn<Result, Parent, ContextType, Args>;
export declare type IAdminIdeSettingsResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['AdminIdeSettings'] = IResolversParentTypes['AdminIdeSettings']> = {
    dummy?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export interface IAnyObjectScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['AnyObject'], any> {
    name: 'AnyObject';
}
export interface IDateScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['Date'], any> {
    name: 'Date';
}
export interface IDateTimeScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['DateTime'], any> {
    name: 'DateTime';
}
export declare type IEmptyResponseResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['EmptyResponse'] = IResolversParentTypes['EmptyResponse']> = {
    alwaysNil?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IFieldErrorResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['FieldError'] = IResolversParentTypes['FieldError']> = {
    field?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    message?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IGeoLocationResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['GeoLocation'] = IResolversParentTypes['GeoLocation']> = {
    type?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    coordinates?: Resolver<Maybe<Array<Maybe<IResolversTypes['Float']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IHelmCommandsGlobalFlagsResolvers = EnumResolverSignature<{
    DEBUG_FLAG?: any;
}, IResolversTypes['HelmCommandsGlobalFlags']>;
export declare type IHelmGetChartResourcesRequestResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['HelmGetChartResourcesRequest'] = IResolversParentTypes['HelmGetChartResourcesRequest']> = {
    chartName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    chartVersion?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    values?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    setValues?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IHelmInspectFlagsResolvers = EnumResolverSignature<{
    CA_FILE_FLAG?: any;
    CERT_FILE_FLAG?: any;
    KEY_FILE_FLAG?: any;
    KEYRING_FLAG?: any;
    PASSWORD_FLAG?: any;
    REPO_FLAG?: any;
    USERNAME_FLAG?: any;
    VERSION_FLAG?: any;
}, IResolversTypes['HelmInspectFlags']>;
export declare type IHelmInspectRequestResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['HelmInspectRequest'] = IResolversParentTypes['HelmInspectRequest']> = {
    helmInspectCommand?: Resolver<Maybe<IResolversTypes['HelmInspectCommands']>, ParentType, ContextType>;
    chartName?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    OptionalInspectFlags?: Resolver<Maybe<Array<Maybe<IResolversTypes['OptionalInspectFlags']>>>, ParentType, ContextType>;
    OptionalGlobalFlags?: Resolver<Maybe<Array<Maybe<IResolversTypes['HelmCommandsGlobalFlags']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IHelmInstallFlagsResolvers = EnumResolverSignature<{
    SET?: any;
    NAME?: any;
    NAME_SPACE?: any;
}, IResolversTypes['HelmInstallFlags']>;
export declare type IHelmInstallTillerRequestResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['HelmInstallTillerRequest'] = IResolversParentTypes['HelmInstallTillerRequest']> = {
    nameSpace?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IHelmRepoAddRequestResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['HelmRepoAddRequest'] = IResolversParentTypes['HelmRepoAddRequest']> = {
    helmRepoCommand?: Resolver<IResolversTypes['HelmRepoCommands'], ParentType, ContextType>;
    repoName?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    url?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    OptionalRepoFlags?: Resolver<Maybe<Array<Maybe<IResolversTypes['OptionalRepoFlags']>>>, ParentType, ContextType>;
    OptionalGlobalFlags?: Resolver<Maybe<Array<Maybe<IResolversTypes['HelmCommandsGlobalFlags']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IHelmRepoFlagsResolvers = EnumResolverSignature<{
    CA_FILE_FLAG?: any;
    CERT_FILE_FLAG?: any;
    KEY_FILE_FLAG?: any;
    PASSWORD_FLAG?: any;
    USERNAME_FLAG?: any;
    No_UPDATE_FLAG?: any;
}, IResolversTypes['HelmRepoFlags']>;
export declare type IHelmSearchFlagsResolvers = EnumResolverSignature<{
    REGEXP?: any;
    VERSION?: any;
    VERSIONS?: any;
}, IResolversTypes['HelmSearchFlags']>;
export declare type IHelmSearchRequestResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['HelmSearchRequest'] = IResolversParentTypes['HelmSearchRequest']> = {
    OptionalRegex?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    OptionalSearchFlags?: Resolver<Maybe<Array<Maybe<IResolversTypes['OptionalSearchFlags']>>>, ParentType, ContextType>;
    OptionalGlobalFlags?: Resolver<Maybe<Array<Maybe<IResolversTypes['HelmCommandsGlobalFlags']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IHelmServiceResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['HelmService'] = IResolversParentTypes['HelmService']> = {
    inspect?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType, RequireFields<IHelmServiceInspectArgs, never>>;
    repoAdd?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType, RequireFields<IHelmServiceRepoAddArgs, never>>;
    search?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType, RequireFields<IHelmServiceSearchArgs, never>>;
    installTiller?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType, RequireFields<IHelmServiceInstallTillerArgs, never>>;
    getResources?: Resolver<Maybe<IResolversTypes['TotalConsumption']>, ParentType, ContextType, RequireFields<IHelmServiceGetResourcesArgs, never>>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IIKubectlLogSettingsResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['IKubectlLogSettings'] = IResolversParentTypes['IKubectlLogSettings']> = {
    __resolveType: TypeResolveFn<'KubectlLogSettings', ParentType, ContextType>;
    subTopic?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
};
export declare type IIResourceUtilizationSettingsResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['IResourceUtilizationSettings'] = IResolversParentTypes['IResourceUtilizationSettings']> = {
    __resolveType: TypeResolveFn<null, ParentType, ContextType>;
    subTopic?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    adminApiNamespace?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
};
export declare type IISshKeySettingsResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['ISshKeySettings'] = IResolversParentTypes['ISshKeySettings']> = {
    __resolveType: TypeResolveFn<'SshKeySettings', ParentType, ContextType>;
    subTopic?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    sshNamespace?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
};
export interface IJsonScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['JSON'], any> {
    name: 'JSON';
}
export interface IJsonObjectScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['JSONObject'], any> {
    name: 'JSONObject';
}
export declare type IKubectlCmdFlagsResolvers = EnumResolverSignature<{
    LABEL?: any;
    TAIL?: any;
    STREAM?: any;
    NAMESPACE?: any;
    CONTAINER?: any;
    TIMESTAMPS?: any;
}, IResolversTypes['KubectlCmdFlags']>;
export declare type IKubectlLogGetRequestResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['KubectlLogGetRequest'] = IResolversParentTypes['KubectlLogGetRequest']> = {
    labelKey?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    labelValue?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    nameSpace?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    tail?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    stream?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    timeStamp?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IKubectlLogSettingsResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['KubectlLogSettings'] = IResolversParentTypes['KubectlLogSettings']> = {
    subTopic?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IKubectlLoggerServiceResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['KubectlLoggerService'] = IResolversParentTypes['KubectlLoggerService']> = {
    getLogs?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType, RequireFields<IKubectlLoggerServiceGetLogsArgs, never>>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IKubectlServiceResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['KubectlService'] = IResolversParentTypes['KubectlService']> = {
    exposePort?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IKubectlServiceExposePortArgs, never>>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IMutationResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['Mutation'] = IResolversParentTypes['Mutation']> = {
    AddSshKey?: Resolver<Maybe<IResolversTypes['SshKey']>, ParentType, ContextType, RequireFields<IMutationAddSshKeyArgs, 'key'>>;
    DeleteSshKey?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<IMutationDeleteSshKeyArgs, 'id'>>;
    UpdateSshKey?: Resolver<Maybe<IResolversTypes['SshKey']>, ParentType, ContextType, RequireFields<IMutationUpdateSshKeyArgs, 'id' | 'key'>>;
    dummy?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
};
export declare type INodeResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['Node'] = IResolversParentTypes['Node']> = {
    __resolveType: TypeResolveFn<null, ParentType, ContextType>;
    id?: Resolver<IResolversTypes['ID'], ParentType, ContextType>;
};
export interface IObservableScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['Observable'], any> {
    name: 'Observable';
}
export declare type IOptionalInspectFlagsResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['OptionalInspectFlags'] = IResolversParentTypes['OptionalInspectFlags']> = {
    flag?: Resolver<Maybe<IResolversTypes['HelmInspectFlags']>, ParentType, ContextType>;
    value?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IOptionalRepoFlagsResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['OptionalRepoFlags'] = IResolversParentTypes['OptionalRepoFlags']> = {
    flag?: Resolver<Maybe<IResolversTypes['HelmRepoFlags']>, ParentType, ContextType>;
    value?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IOptionalSearchFlagsResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['OptionalSearchFlags'] = IResolversParentTypes['OptionalSearchFlags']> = {
    flag?: Resolver<Maybe<IResolversTypes['HelmSearchFlags']>, ParentType, ContextType>;
    value?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IPageInfoResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['PageInfo'] = IResolversParentTypes['PageInfo']> = {
    hasNextPage?: Resolver<IResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IQueryResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['Query'] = IResolversParentTypes['Query']> = {
    GetSshKey?: Resolver<Maybe<IResolversTypes['SshKey']>, ParentType, ContextType, RequireFields<IQueryGetSshKeyArgs, 'id'>>;
    node?: Resolver<Maybe<IResolversTypes['Node']>, ParentType, ContextType, RequireFields<IQueryNodeArgs, 'id'>>;
};
export declare type IRequestsLimitsResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['RequestsLimits'] = IResolversParentTypes['RequestsLimits']> = {
    storage?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    cpu?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    memory?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IResourcesResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['Resources'] = IResolversParentTypes['Resources']> = {
    requests?: Resolver<Maybe<Array<Maybe<IResolversTypes['RequestsLimits']>>>, ParentType, ContextType>;
    limits?: Resolver<Maybe<Array<Maybe<IResolversTypes['RequestsLimits']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type ISshKeyResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['SshKey'] = IResolversParentTypes['SshKey']> = {
    id?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    key?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    pubKey?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    keyType?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    createdAt?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type ISshKeyModelResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['SshKeyModel'] = IResolversParentTypes['SshKeyModel']> = {
    id?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    name?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    keyType?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    createdAt?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type ISshKeyServiceResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['SshKeyService'] = IResolversParentTypes['SshKeyService']> = {
    addSshKey?: Resolver<Maybe<IResolversTypes['SshKeyModel']>, ParentType, ContextType, RequireFields<ISshKeyServiceAddSshKeyArgs, never>>;
    deleteSshKey?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType, RequireFields<ISshKeyServiceDeleteSshKeyArgs, never>>;
    generateKeys?: Resolver<Maybe<IResolversTypes['SshKeyModel']>, ParentType, ContextType, RequireFields<ISshKeyServiceGenerateKeysArgs, never>>;
    getSshKey?: Resolver<Maybe<IResolversTypes['SshKeyModel']>, ParentType, ContextType, RequireFields<ISshKeyServiceGetSshKeyArgs, never>>;
    updateSshKey?: Resolver<Maybe<IResolversTypes['SshKeyModel']>, ParentType, ContextType, RequireFields<ISshKeyServiceUpdateSshKeyArgs, never>>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type ISshKeySettingsResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['SshKeySettings'] = IResolversParentTypes['SshKeySettings']> = {
    subTopic?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    sshNamespace?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type ISternCmdFlagsResolvers = EnumResolverSignature<{
    LABEL?: any;
    NAMESPACE?: any;
    TIMESTAMPS?: any;
    TAIL?: any;
    CONTAINER?: any;
}, IResolversTypes['SternCmdFlags']>;
export declare type ISubscriptionResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['Subscription'] = IResolversParentTypes['Subscription']> = {
    dummy?: SubscriptionResolver<Maybe<IResolversTypes['Int']>, "dummy", ParentType, ContextType>;
};
export interface ITimeScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['Time'], any> {
    name: 'Time';
}
export declare type ITotalConsumptionResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['TotalConsumption'] = IResolversParentTypes['TotalConsumption']> = {
    request?: Resolver<Maybe<IResolversTypes['RequestsLimits']>, ParentType, ContextType>;
    limits?: Resolver<Maybe<IResolversTypes['RequestsLimits']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export interface IUriScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['URI'], any> {
    name: 'URI';
}
export interface IUriInputScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['URIInput'], any> {
    name: 'URIInput';
}
export declare type IResolvers<ContextType = MyContext> = {
    AdminIdeSettings?: IAdminIdeSettingsResolvers<ContextType>;
    AnyObject?: GraphQLScalarType;
    Date?: GraphQLScalarType;
    DateTime?: GraphQLScalarType;
    EmptyResponse?: IEmptyResponseResolvers<ContextType>;
    FieldError?: IFieldErrorResolvers<ContextType>;
    GeoLocation?: IGeoLocationResolvers<ContextType>;
    HelmCommandsGlobalFlags?: IHelmCommandsGlobalFlagsResolvers;
    HelmGetChartResourcesRequest?: IHelmGetChartResourcesRequestResolvers<ContextType>;
    HelmInspectFlags?: IHelmInspectFlagsResolvers;
    HelmInspectRequest?: IHelmInspectRequestResolvers<ContextType>;
    HelmInstallFlags?: IHelmInstallFlagsResolvers;
    HelmInstallTillerRequest?: IHelmInstallTillerRequestResolvers<ContextType>;
    HelmRepoAddRequest?: IHelmRepoAddRequestResolvers<ContextType>;
    HelmRepoFlags?: IHelmRepoFlagsResolvers;
    HelmSearchFlags?: IHelmSearchFlagsResolvers;
    HelmSearchRequest?: IHelmSearchRequestResolvers<ContextType>;
    HelmService?: IHelmServiceResolvers<ContextType>;
    IKubectlLogSettings?: IIKubectlLogSettingsResolvers<ContextType>;
    IResourceUtilizationSettings?: IIResourceUtilizationSettingsResolvers<ContextType>;
    ISshKeySettings?: IISshKeySettingsResolvers<ContextType>;
    JSON?: GraphQLScalarType;
    JSONObject?: GraphQLScalarType;
    KubectlCmdFlags?: IKubectlCmdFlagsResolvers;
    KubectlLogGetRequest?: IKubectlLogGetRequestResolvers<ContextType>;
    KubectlLogSettings?: IKubectlLogSettingsResolvers<ContextType>;
    KubectlLoggerService?: IKubectlLoggerServiceResolvers<ContextType>;
    KubectlService?: IKubectlServiceResolvers<ContextType>;
    Mutation?: IMutationResolvers<ContextType>;
    Node?: INodeResolvers<ContextType>;
    Observable?: GraphQLScalarType;
    OptionalInspectFlags?: IOptionalInspectFlagsResolvers<ContextType>;
    OptionalRepoFlags?: IOptionalRepoFlagsResolvers<ContextType>;
    OptionalSearchFlags?: IOptionalSearchFlagsResolvers<ContextType>;
    PageInfo?: IPageInfoResolvers<ContextType>;
    Query?: IQueryResolvers<ContextType>;
    RequestsLimits?: IRequestsLimitsResolvers<ContextType>;
    Resources?: IResourcesResolvers<ContextType>;
    SshKey?: ISshKeyResolvers<ContextType>;
    SshKeyModel?: ISshKeyModelResolvers<ContextType>;
    SshKeyService?: ISshKeyServiceResolvers<ContextType>;
    SshKeySettings?: ISshKeySettingsResolvers<ContextType>;
    SternCmdFlags?: ISternCmdFlagsResolvers;
    Subscription?: ISubscriptionResolvers<ContextType>;
    Time?: GraphQLScalarType;
    TotalConsumption?: ITotalConsumptionResolvers<ContextType>;
    URI?: GraphQLScalarType;
    URIInput?: GraphQLScalarType;
};
export declare type IDirectiveResolvers<ContextType = MyContext> = {
    cacheControl?: ICacheControlDirectiveResolver<any, any, ContextType>;
};
